Mémo sur les services solaris10
par
popularité : 2%
Mémo sur les services solaris10
· Activer ou désactiver un service au démarrage du système
|
· Gérer un service : stop / start / restart
|
- Connaitre les services en erreurs :
# svcs -x
svc :/network/ntp:default (Network Time Protocol (NTP).)
State : maintenance since Mon Oct 18 13:58:42 2004
Reason : Start method exited with $SMF_EXIT_ERR_CONFIG.
See : http://sun.com/msg/SMF-8000-KS
See : ntpq(1M)
See : ntpdate(1M)
See : xntpd(1M)
Impact : 0 services are not running.
- Connaitre les impactes des services en erreurs.
# svcs -x -v
svc :/application/print/server:default (LP Print Service)
State : disabled since Mon Oct 18 16:17:27 2004
Reason : Disabled by an administrator.
See : http://sun.com/msg/SMF-8000-05
See : man -M /usr/share/man -s 1M lpsched
Impact : 1 service is not running :
svc :/application/print/rfc1179:default
- Connaitre les processus associés a un services
% svcs -p network/smtp:sendmail
STATE STIME FMRI
online 18:20:30 svc :/network/smtp:sendmail
18:20:30 655 sendmail
18:20:30 657 sendmail
% ps -fp 655,657
UID PID PPID C STIME TTY TIME CMD
root 655 1 0 18:20:30 ? 0:01 /usr/lib/sendmail -bd -q15m
smmsp 657 1 0 18:20:30 ? 0:00 /usr/lib/sendmail -Ac -q15m
- Connaitre les services qui dépende d’un autre (ici sendmail)
% svcs -d network/smtp:sendmail
STATE STIME FMRI
online 18:20:14 svc :/system/identity:domain
online 18:20:26 svc :/network/service:default
online 18:20:27 svc :/system/filesystem/local:default
online 18:20:27 svc :/milestone/name-services:default
online 18:20:27 svc :/system/system-log:default
online 18:20:30 svc :/system/filesystem/autofs:default
- Connaitre le/les service(s) nécessaire(s) pour lancer un service donné (ici sendmail, autofs)
% svcs -D network/smtp:sendmail
STATE STIME FMRI
online 18:20:32 svc :/milestone/multi-user:default
% svcs -D /system/filesystem/autofs:default
STATE STIME FMRI
disabled Feb_10 svc :/network/http:apache2
online Feb_10 svc :/network/ssh:default
online Feb_10 svc :/system/system-log:default
online Feb_10 svc :/network/smtp:sendmail
online Feb_10 svc :/milestone/multi-user:default
- modifier des commandes/options dans un service
# inetadm -l svc :/network/ftp:default | grep exec
exec="/usr/sbin/in.ftpd -a"
# inetadm -m svc :/network/ftp:default exec="/usr/sbin/in.ftpd -a -l"
# inetadm -l svc :/network/ftp:default
SCOPE NAME=VALUE
name="ftp"
endpoint_type="stream"
proto="tcp6"
isrpc=FALSE
wait=FALSE
exec="/usr/sbin/in.ftpd -a -l"
Memo :
| Service Name | FMRI | Run Script | inetd Service |
| automount | svc :/system/filesystem/autofs:default | autofs | Not applicable |
| consadmd | svc :/system/consadm:default | rootusr | Not applicable |
| coreadm | svc :/system/coreadm:default | coreadm | Not applicable |
| cron | svc :/system/cron:default | cron | Not applicable |
| cryptoadm | svc :/system/cryptosvc:default | N/A | Not applicable |
| cvcd | svc :/system/cvc:default | cvcd | Not applicable |
| dcs | svc :/platform/<arch>/dcs:default | None | Applicable |
| dtlogin | svc :/application/graphical-login/cde-login:default | dtlogin | Not applicable |
| dtprintinfo | svc :/application/cde-printinfo:default | dtlogin | Not applicable |
| dtspcd | svc :/network/cde-spc:default | None | Applicable |
| dumpadm | svc :/system/dumpadm:default | savecore | Not applicable |
| efdaemon | svc :/platform/<arch>/efdaemon:default | efcode | Not applicable |
| fmd | svc :/system/fmd:default | N/A | Not applicable |
| gssd | svc :/network/rpc/gss:default | None | Applicable |
| imapd | svc :/network/imap/tcp:default svc :/network/imapnew/tcp:default | None | Applicable |
| in.chargend | svc :/network/chargen:dgram svc :/network/chargen:stream | None | Applicable |
| in.comsat | svc :/network/comsat:default | None | Applicable |
| in.daytimed | svc :/network/daytime:dgram svc :/network/daytime:stream | None | Applicable |
| in.dhcpd | svc :/network/dhcp-server:default | dhcp | Not applicable |
| in.discardd | svc :/network/discard:dgram svc :/network/discard:stream | None | Applicable |
| in.echod | svc :/network/echo:dgram svc :/network/echo:stream | None | Applicable |
| in.fingerd | svc :/network/finger:default | None | Applicable |
| in.ftpd | svc :/network/ftp:default | None | Applicable |
| in.named | svc :/network/dns/server:default | inetsvc | Not applicable |
| in.rarpd | svc :/network/rarp:default | boot.server | Not applicable |
| in.rdisc | svc :/network/initial:default | inetinit | Not applicable |
| in.rexecd | svc :/network/rexec:default | None | Applicable |
| in.rlogind | svc :/network/login:rlogin svc :/network/login:eklogin svc :/network/login:klogin | None | Applicable |
| in.routed | svc :/network/initial:default | inetinit | Not applicable |
| in.rshd | svc :/network/shell:default svc :/network/kshell | None | Applicable |
| in.talkd | svc :/network/talk:default | None | Applicable |
| in.telnetd | svc :/network/telnet:default | None | Applicable |
| in.tftpd | svc :/network/tftp/udp6:default | None | Applicable |
| in.timed | svc :/network/time:dgram svc :/network/time:stream | None | Applicable |
| in.tnamed | svc :/network/tname:default | None | Applicable |
| in.uucpd | svc :/network/uucp:default | None | Applicable |
| inetd-upgrade | svc :/network/inetd-upgrade:default | N/A | Not applicable |
| inetd | svc :/network/inetd:default | inetsvc | Not applicable |
| intrd | svc :/system/intrd:default | None | Not applicable |
| ipop3d | svc :/network/pop3/tcp:default | None | Applicable |
| kadmind | svc :/network/security/kadmin:default | kdc.master | Not applicable |
| kbd | svc :/system/keymap:default | keymap | Not applicable |
| keyserv | svc :/network/rpc/keyserv:default | rpc | Not applicable |
| kpropd | svc :/network/security/krb5_prop:default | None | Applicable |
| krb5kdc | svc :/network/security/krb5kdc:default | kdc | Not applicable |
| ktkt_warnd | svc :/network/security/ktkt_warn:default | None | Applicable |
| ldap_cachemgr | svc :/network/ldap/client:default | ldap.client | Not applicable |
| loadkeys | svc :/system/keymap:default | keymap | Not applicable |
| lockd | svc :/network/nfs/client:default svc :/network/nfs/server:default | nfs.server | Not applicable |
| lpsched and lpshut | svc :/application/print/server:default | lp | Not applicable |
| mdmonitord | svc :/system/mdmonitor:default | svm.sync | Not applicable |
| metainit | svc :/system/metainit:default | svm.init | Not applicable |
| metadevadm | svc :/platform/<arch>/mpxio-upgrade:default | N/A | Not applicable |
| mount | svc :/system/filesystem/local:default svc :/system/filesystem/minimal:default svc :/system/filesystem/root:default svc :/system/filesystem/usr:default | nfs.client, rootusr, standardmounts | Not applicable |
| mountd | svc :/network/nfs/server:default | nfs.server | Not applicable |
| nfsd | svc :/network/nfs/server:default | nfs.server | Not applicable |
| nfsmapid | svc :/network/nfs/client:default svc :/network/nfs/server:default | nfs.server | Not applicable |
| nis_cachemgr | svc :/network/rpc/nisplus:default | rpc | Not applicable |
| nscd | svc :/system/name-service-cache:default | nscd | Not applicable |
| ntpdate | svc :/network/ntp:default | xntpd | Not applicable |
| ocfserv | svc :/network/rpc/ocfserv:default | ocfserv | Not applicable |
| picld | svc :/system/picl:default | picld | Not applicable |
| pmconfig | svc :/system/power:default | power | Not applicable |
| printd | svc :/application/print/cleanup:default | spc | Not applicable |
| quotaon | svc :/system/filesystem/local:default | ufs_quota | Not applicable |
| rcapd | svc :/system/rcap:default | rcapd | Not applicable |
| rpcbind | svc :/network/rpc/bind:default | rpc | Not applicable |
| rpc.bootparamd | svc :/network/rpc/bootparams:default | boot.server | Not applicable |
| rpc.mdcomm | svc :/network/rpc/mdcomm:default | None | Applicable |
| rpc.metad | svc :/network/rpc/meta:default | None | Applicable |
| rpc.metamedd | svc :/network/rpc/metamed:default | None | Applicable |
| rpc.metamhd | svc :/network/rpc/metamh:default | None | Applicable |
| rpc.nisd | svc :/network/rpc/nisplus:default | rpc | Not applicable |
| rpc.nispasswdd | svc :/network/rpc/nisplus:default | rpc | Not applicable |
| rpc.rexd | svc :/network/rpc/rex:default | None | Applicable |
| rpc.rstatd | svc :/network/rpc/rstat:default | None | Applicable |
| rpc.rusersd | svc :/network/rpc/rusers:default | None | Applicable |
| rpc.smserverd | svc :/network/rpc/smserver:default | None | Applicable |
| rpc.sprayd | svc :/network/rpc/spray:default | None | Applicable |
| rpc.ttdbserverd | svc :/network/rpc/ttdbserver:tcp | None | Applicable |
| rpc.walld | svc :/network/rpc/wall:default | None | Applicable |
| rpc.yppasswdd and rpc.ypupdated | svc :/network/nis/server:default | rpc | Not applicable |
| rquotad | svc :/network/nfs/rquota:default | None | Applicable |
| sadc | svc :/system/sar:default | perf | Not applicable |
| savecore | svc :/system/dumpadm:default | savecore | Not applicable |
| sendmail | svc :/network/smtp:sendmail | sendmail | Not applicable |
| sf880drd | svc :/platform/<arch>/sf880drd:default | sf880dr | Not applicable |
| slpd | svc :/network/slp:default | slpd | Not applicable |
| sshd | svc :/network/ssh:default | sshd | Not applicable |
| statd | svc :/network/nfs/client:default svc :/network/nfs/server:default | nfs.server | Not applicable |
| svc.startd | svc :/system/svc/restarter:default | N/A | Not applicable |
| syseventd | svc :/system/sysevent:default | devfsadm | Not applicable |
| sysidpm, sysidns, sysidroot, sysidsys | svc :/system/sysidtool:system | sysid.sys | Not applicable |
| sysidnet | svc :/system/sysidtool:net | sysid.net | Not applicable |
| syslogd | svc :/system/system-log:default | syslog | Not applicable |
| ttymon | svc :/system/console-login:default | inittab | Not applicable |
| utmpd | svc :/system/utmp:default | utmpd | Not applicable |
| vold | svc :/system/filesystem/volfs:default | volmgt | Not applicable |
| xntpd | svc :/network/ntp:default | xntpd | Not applicable |
| ypbind | svc :/network/nis/client:default | rpc | Not applicable |
| ypserv | svc :/network/nis/server:default | rpc | Not applicable |
| ypxfrd | svc :/network/nis/server:default | rpc | Not applicable |
| zoneadm | svc :/system/zones:default | N/A | Not applicable |
| None | svc :/network/loopback:default | network | Not applicable |
| None | svc :/network/physical:default | network | Not applicable |


Commentaires Forum fermé